@@ -1,5 +1,7 @@
 """
-Main interface for sagemaker-featurestore-runtime service type definitions.
+Type annotations for sagemaker-featurestore-runtime service type definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_featurestore_runtime/type_defs.html)
 
 Usage::
 
@@ -20,8 +22,11 @@ else:
 
 __all__ = ("FeatureValueTypeDef", "GetRecordResponseTypeDef")
 
-FeatureValueTypeDef = TypedDict("FeatureValueTypeDef", {"FeatureName": str, "ValueAsString": str})
 
-GetRecordResponseTypeDef = TypedDict(
-    "GetRecordResponseTypeDef", {"Record": List["FeatureValueTypeDef"]}, total=False
-)
+class FeatureValueTypeDef(TypedDict):
+    FeatureName: str
+    ValueAsString: str
+
+
+class GetRecordResponseTypeDef(TypedDict, total=False):
+    Record: List["FeatureValueTypeDef"]
